@@ -33,7 +33,6 @@ static const char extraDetailsLabelMargin[] = " margin: 5px; ";
 BacktraceWidget::BacktraceWidget(BacktraceGenerator *generator, QWidget *parent, bool showToggleBacktrace)
     : QWidget(parent)
     , m_btGenerator(generator)
-    , m_highlighter(nullptr)
 {
     ui.setupUi(this);
 
@@ -161,7 +160,7 @@ void BacktraceWidget::regenerateBacktrace()
         anotherDebuggerRunning();
     }
 
-    emit stateChanged();
+    Q_EMIT stateChanged();
 }
 
 void BacktraceWidget::generateBacktrace()
@@ -172,11 +171,11 @@ void BacktraceWidget::generateBacktrace()
     } else if (m_btGenerator->state() == BacktraceGenerator::Loading) {
         // Set in loading state, the widget will catch the backtrace events anyway
         setAsLoading();
-        emit stateChanged();
+        Q_EMIT stateChanged();
     } else {
         //*Finished* states
         setAsLoading();
-        emit stateChanged();
+        Q_EMIT stateChanged();
         // Load already generated information
         loadData();
     }
@@ -328,7 +327,7 @@ void BacktraceWidget::loadData()
 
     ui.m_reloadBacktraceButton->setEnabled(true);
 
-    emit stateChanged();
+    Q_EMIT stateChanged();
 }
 
 void BacktraceWidget::backtraceNewLine(const QString &line)
@@ -348,12 +347,12 @@ void BacktraceWidget::saveClicked()
     DrKonqi::saveReport(m_btGenerator->backtrace(), this);
 }
 
-void BacktraceWidget::hilightExtraDetailsLabel(bool hilight)
+void BacktraceWidget::highlightExtraDetailsLabel(bool highlight)
 {
-    const QString stylesheet = ((!hilight) ? QLatin1String("border-width: 0px;")
-                                           : QLatin1String("border-width: 2px; "
-                                                           "border-style: solid; "
-                                                           "border-color: red;"))
+    const QString stylesheet = ((!highlight) ? QLatin1String("border-width: 0px;")
+                                             : QLatin1String("border-width: 2px; "
+                                                             "border-style: solid; "
+                                                             "border-color: red;"))
         + QLatin1String(extraDetailsLabelMargin);
 
     ui.m_extraDetailsLabel->setStyleSheet(stylesheet);
@@ -410,7 +409,7 @@ void BacktraceWidget::extraDetailsLinkActivated(QString link)
         QString message = QStringLiteral("<html>") + i18n("The packages containing debug information for the following application and libraries are missing:")
             + QStringLiteral("<br /><ul>");
 
-        Q_FOREACH (const QString &string, missingDbgForFiles) {
+        for (const QString &string : std::as_const(missingDbgForFiles)) {
             message += QLatin1String("<li>") + string + QLatin1String("</li>");
         }
 
