@@ -193,7 +193,7 @@ void BugzillaManager::fetchBugReport(int bugnumber, QObject *jobOwner)
 
     Bugzilla::BugClient client;
     auto job = m_searchJob = client.search(search);
-    connect(job, &KJob::finished, this, [this, &client, jobOwner](KJob *job) {
+    connect(job, &KJob::finished, this, [this, client, jobOwner](KJob *job) {
         try {
             auto list = client.search(job);
             if (list.size() != 1) {
@@ -213,7 +213,7 @@ void BugzillaManager::fetchComments(const Bugzilla::Bug::Ptr &bug, QObject *jobO
 {
     Bugzilla::CommentClient client;
     auto job = client.getFromBug(bug->id());
-    connect(job, &KJob::finished, this, [this, &client, jobOwner](KJob *job) {
+    connect(job, &KJob::finished, this, [this, client, jobOwner](KJob *job) {
         try {
             auto comments = client.getFromBug(job);
             Q_EMIT commentsFetched(comments, jobOwner);
@@ -225,7 +225,7 @@ void BugzillaManager::fetchComments(const Bugzilla::Bug::Ptr &bug, QObject *jobO
 }
 
 // TODO: This would kinda benefit from an actual pagination class,
-// currently this implicitly relies on the caller to handle offests correctly.
+// currently this implicitly relies on the caller to handle offsets correctly.
 // Fortunately we only have one caller so it makes no difference.
 void BugzillaManager::searchBugs(const QStringList &products, const QString &severity, const QString &comment, int offset)
 {
@@ -246,7 +246,7 @@ void BugzillaManager::searchBugs(const QStringList &products, const QString &sev
 
     Bugzilla::BugClient client;
     auto job = m_searchJob = Bugzilla::BugClient().search(search);
-    connect(job, &KJob::finished, this, [this, &client](KJob *job) {
+    connect(job, &KJob::finished, this, [this, client](KJob *job) {
         try {
             auto list = client.search(job);
             m_searchJob = nullptr;
@@ -322,7 +322,7 @@ void BugzillaManager::fetchProductInfo(const QString &product)
         try {
             auto ptr = Bugzilla::ProductClient().get(job);
             Q_ASSERT(ptr);
-            productInfoFetched(ptr);
+            Q_EMIT productInfoFetched(ptr);
         } catch (Bugzilla::Exception &e) {
             qCWarning(DRKONQI_LOG) << e.whatString();
             // This doesn't have a string because it is actually not used for
