@@ -13,12 +13,13 @@
 
 #include <KJob>
 
-namespace KIO {
+namespace KIO
+{
 class TransferJob;
 }
 
-namespace Bugzilla {
-
+namespace Bugzilla
+{
 class APIJob : public KJob
 {
     Q_OBJECT
@@ -46,7 +47,9 @@ public:
     virtual QByteArray data() const = 0;
 
 private:
-    virtual void start() override {}
+    virtual void start() override
+    {
+    }
     virtual void connectNotify(const QMetaMethod &signal) override;
 
     bool m_autostart = true;
@@ -57,7 +60,10 @@ class TransferAPIJob : public APIJob
     Q_OBJECT
     friend class HTTPConnection; // constructs us, ctor is private though
 public:
-    virtual QByteArray data() const override { return m_data; }
+    virtual QByteArray data() const override
+    {
+        return m_data;
+    }
 
 private:
     explicit TransferAPIJob(KIO::TransferJob *transferJob, QObject *parent = nullptr);
