@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,6 +8,7 @@
 
 #include <KConfig>
 #include <KConfigGroup>
+#include <KFileUtils>
 #include <KMacroExpander>
 #include <QCoreApplication>
 #include <QDir>
@@ -75,16 +77,34 @@ void Debugger::setUsedBackend(const QString &backendName)
 
 QString Debugger::command() const
 {
-    return (isValid() && m_config->hasGroup(m_backend)) ? m_config->group(m_backend).readPathEntry("Exec", QString()) : QString();
+    if (!isValid() || !m_config->hasGroup(m_backend)) {
+        return {};
+    }
+    return expandCommand(m_config->group(m_backend).readPathEntry("Exec", QString()));
 }
 
 QString Debugger::backtraceBatchCommands() const
 {
-    return (isValid() && m_config->hasGroup(m_backend)) ? m_config->group(m_backend).readPathEntry("BatchCommands", QString()) : QString();
+    if (!isValid() || !m_config->hasGroup(m_backend)) {
+        return {};
+    }
+    return expandCommand(m_config->group(m_backend).readPathEntry("BatchCommands", QString()));
 }
+
 QString Debugger::preambleCommands() const
 {
-    return (isValid() && m_config->hasGroup(m_backend)) ? m_config->group(m_backend).readPathEntry("PreambleCommands", QString()) : QString();
+    if (!isValid() || !m_config->hasGroup(m_backend)) {
+        return {};
+    }
+    return expandCommand(m_config->group(m_backend).readPathEntry("PreambleCommands", QString()));
+}
+
+QString Debugger::expandCommand(const QString &command) const
+{
+    static QHash<QString, QString> map = {
+        {QStringLiteral("drkonqi_datadir"), QStandardPaths::locate(QStandardPaths::AppDataLocation, codeName(), QStandardPaths::LocateDirectory)},
+    };
+    return KMacroExpander::expandMacros(command, map);
 }
 
 bool Debugger::runInTerminal() const
@@ -111,6 +131,7 @@ void Debugger::expandString(QString &str, ExpandStringUsage usage, const QString
         {QLatin1String("tempfile"), tempFile},
         {QLatin1String("preamblefile"), preambleFile},
         {QLatin1String("thread"), QString::number(appInfo->thread())},
+        {QStringLiteral("corefile"), appInfo->m_coreFile},
     };
 
     if (usage == ExpansionUsageShell) {
@@ -128,21 +149,45 @@ QList<Debugger> Debugger::availableDebuggers(const QString &path, const QString
                                    QCoreApplication::applicationDirPath() + QLatin1Char('/') + path,
                                    // Search in default path
                                    QStandardPaths::locate(QStandardPaths::AppDataLocation, path, QStandardPaths::LocateDirectory)};
+    const QStringList debuggerFiles = KFileUtils::findAllUniqueFiles(debuggerDirs);
 
-    QHash<QString, Debugger> result;
-    for (const auto &debuggerDir : qAsConst(debuggerDirs)) {
-        const QStringList debuggers = QDir(debuggerDir).entryList(QDir::Files);
-        for (const auto &debuggerFile : qAsConst(debuggers)) {
-            Debugger debugger;
-            debugger.m_config = KSharedConfig::openConfig(debuggerDir + QLatin1Char('/') + debuggerFile);
-            if (result.contains(debugger.codeName())) {
-                continue; // Already found in a higher priority location
-            }
-            if (debugger.supportedBackends().contains(backend)) {
-                debugger.setUsedBackend(backend);
-                result.insert(debugger.codeName(), debugger);
-            }
+    QList<Debugger> result;
+    for (const auto &debuggerFile : debuggerFiles) {
+        Debugger debugger;
+        debugger.m_config = KSharedConfig::openConfig(debuggerFile);
+        if (debugger.supportedBackends().contains(backend)) {
+            debugger.setUsedBackend(backend);
+            result << debugger;
         }
     }
-    return result.values();
+    return result;
+}
+
+Debugger Debugger::findDebugger(const QList<Debugger> &debuggers, const QString &defaultDebuggerCodeName)
+{
+    Debugger firstKnownGoodDebugger;
+    Debugger preferredDebugger;
+    for (const Debugger &debugger : debuggers) {
+        qCDebug(DRKONQI_LOG) << "Check debugger if" << debugger.displayName() << "[" << debugger.codeName() << "]"
+                             << "is installed:" << debugger.isInstalled();
+        if (!firstKnownGoodDebugger.isValid() && debugger.isInstalled()) {
+            firstKnownGoodDebugger = debugger;
+        }
+        if (debugger.codeName() == defaultDebuggerCodeName) {
+            preferredDebugger = debugger;
+        }
+        if (firstKnownGoodDebugger.isValid() && preferredDebugger.isValid()) {
+            break;
+        }
+    }
+
+    if (!preferredDebugger.isInstalled()) {
+        if (firstKnownGoodDebugger.isValid()) {
+            preferredDebugger = firstKnownGoodDebugger;
+        } else {
+            qCWarning(DRKONQI_LOG) << "Unable to find an internal debugger that can work with the crash backend";
+        }
+    }
+
+    return preferredDebugger;
 }
