@@ -9,11 +9,11 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *****************************************************************/
 
-#include "msvc_generator.h"
-#include "mingw_generator.h"
-#include "outputters.h"
-#include "kdbgwin_process.h"
 #include "common.h"
+#include "kdbgwin_process.h"
+#include "mingw_generator.h"
+#include "msvc_generator.h"
+#include "outputters.h"
 
 #include <QCoreApplication>
 
@@ -22,14 +22,12 @@ int main(int argc, char *argv[])
     QCoreApplication app(argc, argv);
     QCoreApplication::setApplicationName(QStringLiteral("kdbgwin"));
 
-    if (argc != 3)
-    {
+    if (argc != 3) {
         qCCritical(DRKONQI_LOG) << "Parameters are incorrect";
         return -1;
     }
 
-    if (!Process::EnableDebugPrivilege())
-    {
+    if (!Process::EnableDebugPrivilege()) {
         qCCritical(DRKONQI_LOG) << "Cannot enable debug privilege, exiting";
         return -1;
     }
@@ -37,8 +35,7 @@ int main(int argc, char *argv[])
     // ok, argv[1] is the pid of the failing process,
     // and argv[2] the current thread id - let's get the info we need
     Process proc;
-    if (!proc.GetInfo(argv[1], argv[2]))
-    {
+    if (!proc.GetInfo(argv[1], argv[2])) {
         qCCritical(DRKONQI_LOG) << "Cannot attach to process, exiting";
         return -1;
     }
@@ -54,8 +51,7 @@ int main(int argc, char *argv[])
     QObject::connect(&generator, &MingwGenerator::DebugLine, &outputter, &Outputter::OnDebugLine);
 
     TThreadsMap::const_iterator it;
-    for (it = proc.GetThreads().constBegin(); it != proc.GetThreads().constEnd(); it++)
-    {
-        generator.Run(it.value(), (it.key() == proc.GetThreadId())? true : false);
+    for (it = proc.GetThreads().constBegin(); it != proc.GetThreads().constEnd(); it++) {
+        generator.Run(it.value(), (it.key() == proc.GetThreadId()) ? true : false);
     }
 }
